#! /bin/bash
#
# Reads specified config file and creates circularly-linked collection
# of numbered HTML worksheets named Worksheet01.html ... Worksheetnn.html,
# where nn < 100.
#

CONFIGFILE="${1:-config}"
declare -r WNAME="Worksheet"

# Must not contain spaces; assumes < 100 worksheet files
function make_fileroot () {
    if [ $1 -lt 10 ]; then
	echo "${WNAME}0$1";
    else
	echo "${WNAME}$1"
    fi
}

function make_filename () {
    echo "$(make_fileroot $1).html"
}

cd files

cat "$CONFIGFILE" | grep -v "#" | while read FILEROOT PAGETITLE
do
    let IDX++
    ../scripts/template.sh "$(make_fileroot $IDX): $PAGETITLE" "$FILEROOT" \
	"$(make_filename $((IDX - 1)))" "$(make_filename $((IDX + 1)))" \
	> "../worksheets/$(make_filename $IDX)"
done

cd ../worksheets

IDX=1
while [ -f "$(make_filename $IDX)" ]; do
    let IDX++
done

let IDX-- # Get index of largest worksheet

# Fix out-of-range "prev" link in Worksheet01 and "next" link in Worksheet$IDX

LASTSHEET="$(make_filename $IDX)"
sed -i "s/$(make_filename 0)/$LASTSHEET/g" "$(make_filename 1)"
sed -i "s/$(make_fileroot $((IDX+1)))/$(make_fileroot 1)/g" "$LASTSHEET"

cd ..

exit 0;
