#! /bin/bash
#
# Write a worksheet page using specified page title and data file.
# This script should be called by the script generate.sh, using
# data from a master configuration file.
#
# Usage: ./template.sh PAGETITLE FILEROOT PAGEPREV PAGENEXT

PAGETITLE="$1"
FILEROOT="$2"
PAGEPREV="$3"
PAGENEXT="$4"

PAGESCAN="$FILEROOT".png
PROOFER_TEXT="$FILEROOT".txt
FOOFER_TEXT="$FILEROOT".tex

cat <<EOF
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<meta http-equiv="Content-Style-Type" content="text/css" />
EOF

echo "<meta http-equiv=\"last-modified\" content=\"$(date --rfc-2822)\" />"

cat <<EOF
<meta name="description" content="LaTeX training worksheets" />
<meta name="robots" content="noindex, nofollow" />

<title>$PAGETITLE</title>

<link rel="stylesheet" type="text/css" href="../css/workbook.css" />
<script type="text/javascript" src="../js/jquery.js"></script>
<script type="text/javascript" src="../js/diff_match_patch.js"></script>
<script type="text/javascript" src="../js/latex_worksheet.js"></script>
</head>

<body>

<div id="worksheet" style="width: 100%">

<div id="header">
<h1>
$PAGETITLE
</h1>
<hr />
</div>

<div id="menu">
<table style="width:100%; float: center;">
<tr>
<td style="width:50%">
<table>
<tr>
<td>
  <a href="$PAGEPREV"><img src="../images/arrow_prev.png" alt="Previous" style="width:50px;" /></a>
</td>
<td>
  <a href="../index.html"><img src="../images/arrow_up.png" alt="Index" style="width:50px;" /></a>
</td>
<td>
<a href="$PAGENEXT"><img src="../images/arrow_next.png" alt="Next" style="width:50px;" /></a>
</td>
</tr>
</table>
</td>
<td style="width:50%; text-align:right;">
<input type="button" id="showdiff" style="display: inline" onclick="show_diff()" value="Check Your Work" />
<input type="button" id="showproof" style="display: none" onclick="show_proof()" value="Continue Editing" />
<input type="button" id="showfoof" style="display: inline" onclick="show_foof()" value="View Answer" />
</td>
</tr>
</table>
<hr />
</div>

<div id="content" style="margin-left: auto; margin-right: auto; width:90%">
<form action="#" onsubmit="return false">

<div id="page_scan" style="overflow: auto; width: 100%; height: 300px;">

<!--<h3>Page Image:</h3>-->

<img src="../images/$PAGESCAN" alt="Page Scan" style="border-style: solid; border-color: black; border-width:1px; width:100%" />
<hr />
</div>

<div id="proofer_area" style="display:block;">

<h3>Current Work (editable)</h3>

<div style="border:solid; border-color: #99ff99; border-width: 3px;">
<textarea id="proofer_text" rows="15" cols="120">
EOF

cat "$PROOFER_TEXT"

cat <<EOF
</textarea>
</div>
<hr />
</div>

<div id="foofer_area" style="display:none;">

<h3>Answer Key (non-editable)</h3>

<div style="border:solid; border-color: #ffa0a0; border-width: 3px;">
<textarea id="foofer_text" readonly="readonly" rows="15" cols="120">
EOF

cat "$FOOFER_TEXT"

cat <<EOF
</textarea>
</div>
<hr />
</div>

<div id="diff_area" style="display:none;">

<h3>Comparison of Current Work and Answer Key</h3>

<p>
<del>Text to be deleted.</del>
<ins>Text to be inserted.</ins>
<span style="color: #dddddd;">&para;</span>&nbsp;symbols signify newlines.
</p>

<hr />

<p id="diff_text" style="width: 100%;"></p>
</div>

</form>
</div> <!-- End of content -->
</div> <!-- End of worksheet -->
</body>
</html>
EOF

exit 0;
